#include <QtGui/QFileDialog>

#include "QMyWindow.h"

QMyWindow::QMyWindow(QWidget *parent): QMainWindow(parent) 
{
	m_ui.setupUi(this);

	connect( m_ui.actionLoadModels, SIGNAL(triggered()), SLOT(slotLoadModels()));
	connect( this, SIGNAL(signalLoadModels(QString)), m_ui.widget, SLOT(slotLoadModels(const QString&)));

	connect( m_ui.actionLoad_Configuration, SIGNAL(triggered()), SLOT(slotLoadConfiguration()));
	connect( this, SIGNAL(signalLoadConfiguration(QString)), m_ui.widget, SLOT(slotLoadConfiguration(const QString&)));
	connect( m_ui.actionSave_Configuration, SIGNAL(triggered()), SLOT(slotSaveConfiguration()));
	connect( this, SIGNAL(signalSaveConfiguration(QString)), m_ui.widget, SLOT(slotSaveConfiguration(const QString&)));

	connect( m_ui.actionLoad_Path, SIGNAL(triggered()), SLOT(slotLoadFlightPath()));
	connect( this, SIGNAL(signalLoadFlightPath(QString)), m_ui.widget, SLOT(slotLoadFlightPath(const QString&)));
	connect( m_ui.actionSave_Path, SIGNAL(triggered()), SLOT(slotSaveFlightPath()));
	connect( this, SIGNAL(signalSaveFlightPath(QString)), m_ui.widget, SLOT(slotSaveFlightPath(const QString&)));


	connect ( m_ui.widget, SIGNAL(signalRenderedObject(int)), m_ui.renderedLcdNumber, SLOT(display(int)) );
	connect ( m_ui.widget, SIGNAL(signalTotalObjects(int)), m_ui.totalLcdNumber, SLOT(display(int)) );

	connect( m_ui.VFCcheckBox, SIGNAL(toggled(bool)), m_ui.widget, SLOT(slotEnableVFC(bool)) );

	connect( m_ui.genPathPushButton, SIGNAL(clicked()), m_ui.widget, SLOT(slotGenerateFlightPath()) );
	connect( m_ui.playPathPushButton, SIGNAL(clicked()), m_ui.widget, SLOT(slotPlayFlightPath()) );

	connect( m_ui.widget, SIGNAL(signalFlightPathAvailable(bool)), m_ui.playPathPushButton, SLOT(setEnabled(bool)) );
	
	connect( m_ui.actionExit, SIGNAL(triggered()), SLOT(slotQuitApp()));

	m_ui.playPathPushButton->setEnabled(m_ui.widget->isFlightPathAvailable());
	m_ui.VFCcheckBox->setChecked(m_ui.widget->isVFCullingEnabled());
}  


void QMyWindow::slotQuitApp() 
{ 
	emit signalQuitApp(); 
}

void QMyWindow::slotLoadModels() 
{ 
	QString s = QFileDialog::getOpenFileName(
                    this,
                    "Load Model List",
                    "./",
                    "File (*.txt)");
	if(!s.isNull())
	{
		emit signalLoadModels(s);
	}
}

void QMyWindow::slotLoadConfiguration() 
{ 
	QString s = QFileDialog::getOpenFileName(
		this,
		"Load Configuration",
		"./",
		"File (*.cfg)");
	if(!s.isNull())
	{
		emit signalLoadConfiguration(s);
	}
}

void QMyWindow::slotSaveConfiguration() 
{ 
	QString s = QFileDialog::getSaveFileName(
		this,
		"Save Configuration",
		"./",
		"File (*.cfg)");
	if(!s.isNull())
	{
		emit signalSaveConfiguration(s);
	}
}

void QMyWindow::slotLoadFlightPath() 
{ 
	QString s = QFileDialog::getOpenFileName(
                    this,
                    "Load Flightpath",
                    "./",
                    "File (*.pth)");
	if(!s.isNull())
	{
		emit signalLoadFlightPath(s);
	}
}

void QMyWindow::slotSaveFlightPath() 
{ 
	QString s = QFileDialog::getSaveFileName(
                    this,
                    "Save Flightpath",
                    "./",
                    "File (*.pth)");
	if(!s.isNull())
	{
		emit signalSaveFlightPath(s);
	}
}
